@@ -1,24 +1,18 @@
-# -* coding: utf-8 -*-
 #
 #  This file is part of Sequana software
 #
-#  Copyright (c) 2016-2021 - Sequana Development Team
-#
-#  File author(s):
-#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
-#      Dimitri Desvillechabrol <dimitri.desvillechabrol@pasteur.fr>,
-#          <d.desvillechabrol@gmail.com>
+#  Copyright (c) 2016-2021 - Sequana Dev Team (https://sequana.readthedocs.io)
 #
 #  Distributed under the terms of the 3-clause BSD license.
 #  The full license is in the LICENSE file, distributed with this software.
 #
-#  website: https://github.com/sequana/sequana
-#  documentation: http://sequana.readthedocs.io
-#
+#  Website:       https://github.com/sequana/sequana
+#  Documentation: http://sequana.readthedocs.io
+#  Contributors:  https://github.com/sequana/sequana/graphs/contributors
 ##############################################################################
 """.. rubric:: misc utilities"""
 
-from sequana_pipetools.misc import Colors
+from .misc import Colors
 
 
 __all__ = ["sequana_epilog"]
@@ -41,8 +35,8 @@ configuration file in the requested working directory ({name} by default).
 Please check out the documentation carefully. In case of issues, please report
 on https://github.com/sequana/sequana/issues or https://github.com/sequana/{name}/issues
 
-Pipelines can be run locally or on a SLURM cluster. If not slurm commands are
-found, te pipeline is in mode 'local', otherwise in mode 'slurm'.
+Pipelines can be run locally or on a SLURM cluster. If no slurm commands are
+found, the pipeline is run in 'local' mode, otherwise in 'slurm' mode.
 
 A working directory called {name} is created with a {name}.sh script to be executed.
 """
