@@ -62,9 +62,11 @@ class SequanaManager:
         self.colors = Colors()
 
         # load the pipeline (to check it is possible and if it is a pipeline)
-        self.module = Module(self.name)
-        if self.module.is_pipeline() is False:
-            raise ValueError("{} does not seem to be installed or is not a valid pipeline".format(self.name))
+        try:
+            self.module = Module(f"pipeline:{self.name}")
+        except ValueError:
+            logger.error(f"{self.name} does not seem to be installed or is not a valid pipeline")
+            sys.exit(1)
         self.module.check()
         #self.module.is_executable()
 
@@ -74,7 +76,8 @@ class SequanaManager:
         self.config = None
         if "from_project" in dir(options) and options.from_project:
             possible_filenames = (
-                options.from_project,  # exact config file path
+                # from project tries to find a valid config.yaml
+                #options.from_project,  # exact config file path
                 f"{options.from_project}/{config_name}",  # config file in project path
                 f"{options.from_project}/.sequana/{config_name}",  # config file in .sequana dir
             )
